@@ -1,9 +1,9 @@
 from rich.console import Console, Group
 from rich.padding import Padding
-from textual import events
 from textual.app import App
 from textual.widgets import ScrollView
 
+from goatpie import GoatPie
 from goatpie.components import GoatBar
 from goatpie.helpers import data2table
 
@@ -13,7 +13,13 @@ class GoatPieApp(App):
     'Goatcounter' analytics at your fingertips
     """
 
-    async def on_load(self, event: events.Load) -> None:
+    # 'GoatPie' instance
+    obj: GoatPie
+
+    # Show last XY entries
+    limit: int
+
+    async def on_load(self) -> None:
         """
         Bind keys
 
@@ -42,6 +48,8 @@ class GoatPieApp(App):
         pages = self.obj.get_pages()
         browsers = self.obj.get_browsers()
         systems = self.obj.get_systems()
+        devices = self.obj.get_devices()
+        countries = self.obj.get_countries()
 
         # Create tables from it & group them together
         tables = Group(
@@ -49,6 +57,8 @@ class GoatPieApp(App):
             Padding(data2table(pages, None)),
             Padding(data2table(browsers, None)),
             Padding(data2table(systems, None)),
+            Padding(data2table(devices, None)),
+            Padding(data2table(countries, None)),
         )
 
         # Query console
