@@ -1,7 +1,6 @@
 from .widget import GoatBar
 
-
 __all__ = [
     # Main class
-    'GoatBar',
+    "GoatBar",
 ]
