@@ -1,3 +1,5 @@
+from typing import Optional
+
 from rich.ansi import AnsiDecoder
 from rich.console import Console, Group
 from rich.jupyter import JupyterMixin
@@ -10,6 +12,15 @@ class plotextRenderable(JupyterMixin):
     'Rich' renderable for plots created with 'plotext'
     """
 
+    # Plot width
+    width: Optional[int] = None
+
+    # Plot height
+    height: Optional[int] = None
+
+    # Plot contents
+    rich_canvas: Optional[Group] = None
+
     def __init__(self, obj, limit: int) -> None:
         """
         Initializes 'plotextRenderable' instance
