@@ -1,8 +1,6 @@
 from typing import Optional
 
-from rich.ansi import AnsiDecoder
-from rich.console import Console
-from rich.padding import Padding, PaddingDimensions
+from rich.padding import Padding
 from rich.panel import Panel
 from textual.widget import Widget
 
@@ -45,9 +43,9 @@ class GoatBar(Widget):
         # Define top padding
         spacing = (1, 0, 0, 0)
 
-        return Padding(Panel(renderable, title="Last {} days".format(self.limit), padding=spacing), spacing)
+        return Padding(Panel(renderable, title=f"Last {self.limit} days", padding=spacing), spacing)
 
-    # TODO: Update data & rerender
+    # FIX: Update data & rerender
     # async def update(self, renderable: RenderableType) -> None:
     #     self.renderable = renderable
     #     self.refresh()
